import axios from 'axios'

class BaseService {
  constructor(path) {
    this.endPoint = path
    this.useApi = 'api2'
    this.token = ''
    this.setBaseUrl()
    this.setToken()
  }

  setToken(token) {
    this.token = token
  }

  setBaseUrl() {
    this.http = axios.create({
      baseURL: 'https://backbone.machinevision.global/cms/api/',
    })
  }

  includeDefault(options) {
    const Authorization = this.token
    this.setBaseUrl()
    const defaultData = {
      headers: {
        Authorization,
      },
    }

    return Object.assign(defaultData, options)
  }

  get(options = {}) {
    const opts = this.includeDefault(options)

    return this.http.get(this.endPoint, opts)
  }

  getOne(id, options = {}) {
    const opts = this.includeDefault(options)
    return this.http.get(`${this.endPoint}/${id}`, opts)
  }

  post(data, options = {}) {
    const opts = this.includeDefault(options)
    return this.http.post(this.endPoint, data, opts)
  }

  postOne(id, data, options = {}) {
    const opts = this.includeDefault(options)
    return this.http.post(`${this.endPoint}/${id}`, data, opts)
  }

  delete(id, options = {}) {
    const opts = this.includeDefault(options)
    return this.http.delete(`${this.endPoint}/${id}`, opts)
  }

  put(data, options = {}) {
    const opts = this.includeDefault(options)
    return this.http.put(this.endPoint, data, opts)
  }

  putOne(id, data, options = {}) {
    const opts = this.includeDefault(options)
    return this.http.put(`${this.endPoint}/${id}`, data, opts)
  }
}

export default BaseService
