import {
  dashboard, widget, insight, type, insightVisualize,
} from '@/services'

export default {
  namespaced: true,
  state: {
    id: null,
    name: 'Dashboard Name',
    slug: '',
    companyId: 0,
    productId: 0,
    description: '',
    additional: null,
    widgets: [],
    insights: [],
    types: [],
  },
  mutations: {
    dashboardCreate(
      state, {
        _id, name, slug, companyId, productId, description, additional,
      },
    ) {
      state.id = _id
      state.name = name
      state.slug = slug
      state.companyId = companyId
      state.productId = productId
      state.description = description
      state.additional = additional
    },
    widgetUpdate(state, { data }) {
      state.widgets = data
    },
    insightUpdate(state, { data }) {
      state.insights = data.map(item => ({
        ...item,
        visualize: {
          loading: true,
          chart: null,
          table: null,
        },
      }))
    },
    typeUpdate(state, { data }) {
      state.types = data
    },
    setVisualize(state, { data, index }) {
      const insights = JSON.parse(JSON.stringify(state.insights))
      const detail = insights[index]
      detail.visualize = {
        chart: data?.chart || null,
        table: data?.table || null,
        loading: false,
      }
      state.insights = insights
    },
  },
  actions: {
    async loadDashboard({ commit, dispatch }, { id, token }) {
      if (!dashboard.token) dashboard.setToken(token)
      const response = await dashboard.getOne(id)
      commit('dashboardCreate', response.data.data)
      /* eslint-disable no-underscore-dangle */
      dispatch('getWidgets', { id: response.data.data._id, token })
    },
    async getWidgets({ commit }, { id, token }) {
      const params = {
        dashboardId: id,
      }
      if (!widget.token) widget.setToken(token)
      const widgets = await widget.get({ params })
      if (widgets?.data?.data?.length) commit('widgetUpdate', widgets?.data)
      return widgets
    },
    async getInsights({ commit }, token) {
      if (!insight.token) insight.setToken(token)
      const insights = await insight.get()
      if (insights?.data?.data?.length) {
        commit('insightUpdate', insights?.data)
      }
      return insights
    },
    async getTypes({ commit }, token) {
      if (!type.token) type.setToken(token)
      const types = await type.get()
      if (types?.data?.data?.length) commit('typeUpdate', types?.data)
      return types
    },
    async fetchInsightsConfig({ state, dispatch }, token) {
      state.insights.forEach((item, index) => dispatch('fetchVisualizeInsight', { config: item.config, index, token }))
    },
    async fetchVisualizeInsight({ commit }, { config, index, token }) {
      if (!insightVisualize.token) insightVisualize.setToken(token)
      const visualize = await insightVisualize.post(config)
      if (visualize?.data?.success) {
        commit('setVisualize', { data: visualize?.data?.data, index })
      }
      return visualize
    },
  },
}
